%exoplanets
% T^2 = a^3/(m+M) is Kepler's Third Law where:
% T is the orbital period /years of a binary system consisting of
% two masses m,M (in units of solar masses). a is the semi-major
% axis of the mutually elliptical orbits, in AU.
%
% This code explores the relationship using exoplanet data.
%
% LAST UPDATED by Dr French. 2/1/2021

function exoplanets

%Set maximum values parameters  (to enable outliers to ignored)
amax = 8; %Semi-major axis in AU
Tmax = 20; %Orbital period in years

%Set fontsize
fsize = 18;

%Mass in kg of Jupiter
mJ = 1.898e27;

%Mass of sun in kg
MS = 1.989e30;

%Year in earth days
year = 365;

%

%Ingest Exoplanet Excel data
[num,txt,raw] = xlsread('Exoplanets raw data.xls');

%Star mass M /solar masses
M = num(:,4); 

%Planet mass m /solar masses
m = num(:,5)*mJ/MS;
m_plus = num(:,9)*mJ/MS;
m_minus = num(:,8)*mJ/MS;

%Orbital period T in years
T = num(:,10)/year;
T_plus = T + num(:,12)/year;
T_minus = T - num(:,11)/year;

%Semi-major axis a in AU
a = num(:,13);
a_plus = a + num(:,15);
a_minus = a - num(:,14);

%

%Form x,y that are predicted to relate as y = 1.00 * x
x =(a.^3)./(m+M);
y = T.^2;

%Sort data by a in ascending order
[a,i] = sort(a);
x = x(i); y = y(i); m = m(i); M = M(i); T = T(i);
a_minus = a_minus(i); a_plus = a_plus(i);
m_minus = m_minus(i); m_plus = m_plus(i);
T_minus = T_minus(i); T_plus = T_plus(i);

%Remove outliers that exceed limits
ignore = (a > amax) | (T > Tmax) ;
x(ignore) = []; y(ignore) = [];
m(ignore) = []; M(ignore) = []; m_minus(ignore) = []; m_plus(ignore) = [];
a(ignore) = []; T(ignore) = []; a_minus(ignore) = []; T_minus(ignore) = [];
a_plus(ignore) = []; T_plus(ignore) = [];

%Find line of best fit to y vs x
[gradient,intercept,yfit,r] = lfit_c_is_0(x,y);
%[gradient,intercept,yfit,r] = lfit(x,y);

%Determine predictions for T given Kepler III
Tmodel = sqrt( (a.^3)./(m+M) );

%%

%Plot orbital period vs semi-major axis
fig1 = figure; plot( a, T, 'r.',a,Tmodel,'b.' ); hold on;
for n=1:length(a)
    %Plot error bars
    plot( [a_minus(n),a_plus(n)],[T(n),T(n)],'g-' );
    plot( [a(n),a(n)],[T_minus(n),T_plus(n)],'g-' );
end
plot( a, T, 'r.',a,Tmodel,'b.' );
xlim([0,amax]); ylim([0,Tmax]);
legend({'Data','Kepler III'},'fontsize',fsize);
set( gca, 'fontsize', fsize );
xlabel('Semi major axis a /AU');
ylabel('Orbital period T /years', 'fontsize', fsize );
title( [ num2str(length(a)),' Exoplanets T vs a']);
grid on; print(gcf,'T vs a.png','-dpng','-r300'); close(gcf);

%Plot T^2 vs (a^3)/(m+M) - hopefully a straight line of gradient 1.00
%if Kepler's Third Law is true. Outliers might be because some planets are
%in binary star systems.
fig2 = figure; plot(x,x,'g-'); hold on
plot(x,y, 'r+',x,yfit,'k-' );
legend({'Kepler III','Data','Linear fit'},'fontsize',fsize);
set( gca, 'fontsize', fsize );
xlabel('(a^3)/(m+M)');
ylabel('T^2');
title({[num2str(length(a)),' Exoplanets T^2 vs (a^3)/(m+M)'],...
    ['y = ',num2str(gradient,4),'x']});
grid on; axis equal; axis tight
print(gcf,'T^2 vs (a^3) over (m+M).png','-dpng','-r300'); close(gcf);

%%

%Linear regression function (y = mx + c)
function [m,c,yfit,r] = lfit(x,y)
cov_xy = mean(x.*y) - mean(x)*mean(y);
Vx = mean(x.^2) - mean(x)^2;
Vy = mean(y.^2) - mean(y)^2;
m = cov_xy/Vx; c = mean(y) - m*mean(x);
yfit = m*x + c; r = cov_xy/sqrt( Vx*Vy );

%%

%Linear regression function (y = mx)
function [m,c,yfit,r] = lfit_c_is_0(x,y)
xybar = mean(x.*y); xxbar = mean(x.^2 ); yybar = mean(y.^2 );
m = xybar/xxbar; c = 0; r = xybar/( xxbar*yybar ); yfit = m*x;

%End of code


